@@ -2,16 +2,14 @@ use std::io::{self, Write};
 
 use crate::utils::colors;
 
+/// Represents a confirmation dialog
 pub struct Confirmation<'a> {
     pub prompt: &'a str,
     pub placeholder: Option<&'a str>,
 }
 
-#[derive(Debug)]
-pub struct Error;
-
 impl<'a> Confirmation<'a> {
-    pub fn new(prompt: &'a str, pattern: Option<&'a str>) -> Self {
+    pub const fn new(prompt: &'a str, pattern: Option<&'a str>) -> Self {
         Self { prompt, placeholder: pattern }
     }
 
@@ -23,14 +21,7 @@ impl<'a> Confirmation<'a> {
         };
 
         loop {
-            print!(
-                "{} [{}Y{}/{}n{}] ",
-                message,
-                colors::green(),
-                colors::reset(),
-                colors::red(),
-                colors::reset()
-            );
+            print!("{} [{}Y{}/{}n{}] ", message, colors::green(), colors::reset(), colors::red(), colors::reset());
             io::stdout().flush()?;
 
             let mut answer = String::new();
@@ -44,7 +35,7 @@ impl<'a> Confirmation<'a> {
             match trimmed_answer.to_ascii_lowercase().as_ref() {
                 "y" | "yes" => return Ok(true),
                 "n" | "no" => return Ok(false),
-                _ => {},
+                _ => {}
             }
         }
     }
